@@ -2,7 +2,7 @@
 /**
  * \file expOutput.c
  *
- *  Time-stamp:        "2010-07-21 17:35:01 bkorb"
+ *  Time-stamp:        "2010-09-05 05:10:51 bkorb"
  *
  *  This module implements the output file manipulation function
  *
@@ -40,6 +40,85 @@ static int            suspAllocCt = 0;
 static tSuspendName*  pSuspended  = NULL;
 static int            outputDepth = 1;
 
+/**
+ * chmod u+w on a file.
+ */
+static void
+make_writable(char* pzFileName)
+{
+    struct stat sbuf;
+
+#ifdef DEBUG_ENABLED
+    /*
+     *  "stat(2)" does not initialize the entire structure.
+     */
+    memset(&sbuf, NUL, sizeof(sbuf));
+#endif
+
+    stat(pzFileName, &sbuf);
+
+    /*
+     *  Or in the user write bit
+     */
+    sbuf.st_mode |= S_IWUSR;
+    chmod(pzFileName, sbuf.st_mode & S_IAMB);
+}
+
+/**
+ * return the current line number
+ */
+static int
+current_line(FILE * fp)
+{
+    int lnno = 1;
+
+    while (! feof(fp)) {
+        int ch = getc(fp);
+        if (ch == '\n')
+            lnno++;
+    }
+
+    return lnno;
+}
+
+/**
+ * guts of the output file/line function
+ */
+static SCM
+do_output_file_line(int line_delta, char const * fmt)
+{
+    char * buf;
+    char const * fname = pCurFp->pzOutName;
+
+    if (pCurFp->flags & FPF_TEMPFILE) {
+        fname = "* temp file *";
+        line_delta = 0;
+
+    } else if (fseek(pCurFp->pFile, 0, SEEK_SET) == 0) {
+        line_delta += current_line(pCurFp->pFile);
+
+    } else {
+        line_delta = 0;
+    }
+
+    {
+        size_t sz = strlen(fmt) + strlen(fname) + 24;
+        buf = ag_scribble(sz);
+    }
+
+    {
+        void * args[2];
+        args[0] = (void *)fname;
+        args[1] = (void *)(uintptr_t)line_delta;
+        sprintfv(buf, fmt, (snv_constpointer *)args);
+    }
+
+    return AG_SCM_STR02SCM(buf);
+}
+
+/**
+ * chmod a-w on a file descriptor.
+ */
 LOCAL void
 make_readonly(int fd)
 {
@@ -70,28 +149,48 @@ make_readonly(int fd)
     fchmod(fd, sbuf.st_mode & S_IAMB);
 }
 
-static void
-make_writable(char* pzFileName)
+/**
+ * Some common code for creating a new file
+ */
+LOCAL void
+open_output_file(char const * fname, size_t nmsz, char const * mode, int flags)
 {
-    struct stat sbuf;
+    char *    pz;
+    tFpStack* p  = AGALOC(sizeof(*p), "out file stack");
 
-#ifdef DEBUG_ENABLED
-    /*
-     *  "stat(2)" does not initialize the entire structure.
-     */
-    memset(&sbuf, NUL, sizeof(sbuf));
-#endif
-
-    stat(pzFileName, &sbuf);
+    pz = (char*)AGALOC(nmsz + 1, "file name string");
+    memcpy(pz, fname, nmsz);
+    pz[ nmsz ] = NUL;
+    memset(p, NUL, sizeof(*p));
+    p->pzOutName = pz;
 
     /*
-     *  Or in the user write bit
+     *  IF we are creating the file and we are allowed to unlink the output,
+     *  then start by unlinking the thing.
      */
-    sbuf.st_mode |= S_IWUSR;
-    chmod(pzFileName, sbuf.st_mode & S_IAMB);
+    if ((*mode == 'w') && ((flags & FPF_NOUNLINK) == 0)) {
+        if ((unlink(pz) != 0) && (errno != ENOENT))
+            AG_CANT("unlink", pz);
+    }
+
+    p->pFile = fopen(pz, mode);
+    if (p->pFile == NULL)
+        AG_CANT("open for output", pz);
+
+    p->pPrev = pCurFp;
+    pCurFp   = p;
+    p->flags = FPF_FREE | flags;
+    outputDepth++;
+
+    make_writable(pz);
+
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf(pfTrace, "open_output_file '%s' mode %s\n", fname, mode);
+
+    if ((pfDepends != NULL) && ((flags & FPF_TEMPFILE) == 0))
+        fprintf(pfDepends, " \\\n\t%s", fname);
 }
 
-
 /*=gfunc out_delete
  *
  * what: delete current output file
@@ -181,41 +280,76 @@ ag_scm_out_pop(SCM ret_contents)
         unsigned long pos = ftell(pCurFp->pFile);
 
         if (pos == 0)
-            res = AG_SCM_STR2SCM("", pos);
+            res = AG_SCM_STR2SCM("", 0);
 
         else {
             char* pz = ag_scribble((size_t)pos);
             rewind(pCurFp->pFile);
             if (fread(pz, (size_t)pos, (size_t)1, pCurFp->pFile) != 1)
-                AG_ABEND(aprf("Error %d (%s) rereading output\n",
-                              errno, strerror(errno)));
+                AG_CANT("re-read output", pCurFp->pzOutName);
             res = AG_SCM_STR2SCM(pz, pos);
         }
     }
 
     if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
-        fputs("out-pop\n", pfTrace);
+        fprintf(pfTrace, "out-pop%s\n", (res == SCM_UNDEFINED) ? "" : " #t");
 
     outputDepth--;
     closeOutput(AG_FALSE);
     return res;
 }
 
+/*=gfunc output_file_next_line
+ *
+ * what:   print the file name and next line number
+ *
+ * exparg: line_off, offset to line number,   optional
+ * exparg: alt_fmt,  alternate format string, optional
+ *
+ * doc:
+ *  Returns a string with the current output file name and line number.
+ *  The default format is: # <line+1> "<output-file-name>" The argument may be
+ *  either a number indicating an offset from the current output line number
+ *  or an alternate formatting string.  If both are provided, then the first
+ *  must be a numeric offset.
+ *
+ *  Be careful that you are directing output to the final output file.
+ *  Otherwise, you will get the file name and line number of the temporary
+ *  file.  That won't be what you want.
+=*/
+SCM
+ag_scm_output_file_next_line(SCM num_or_str, SCM str)
+{
+    char const * pzFmt = "# %2$d \"%1$s\"";
+    int  line_off = 1;
+
+    if (AG_SCM_NUM_P(num_or_str))
+        line_off = gh_scm2long(num_or_str);
+    else
+        str = num_or_str;
+
+    if (AG_SCM_STRING_P(str))
+        pzFmt = ag_scm2zchars(str, "file/line format");
+
+    return do_output_file_line(line_off, pzFmt);
+}
+
 
 /*=gfunc out_suspend
  *
  * what:   suspend current output file
  * exparg: suspName, A name tag for reactivating
+ *
  * doc:
- *  If there has been a @code{push} on the output, then set aside the
- *  output descriptor for later reactiviation with @code{(out-resume "xxx")}.
- *  The tag name need not reflect the name of the output file.  In fact,
- *  the output file may be an anonymous temporary file.  You may also
- *  change the tag every time you suspend output to a file, because the
- *  tag names are forgotten as soon as the file has been "resumed".
+ *  If there has been a @code{push} on the output, then set aside the output
+ *  descriptor for later reactiviation with @code{(out-resume "xxx")}.  The
+ *  tag name need not reflect the name of the output file.  In fact, the
+ *  output file may be an anonymous temporary file.  You may also change the
+ *  tag every time you suspend output to a file, because the tag names are
+ *  forgotten as soon as the file has been "resumed".
 =*/
 SCM
-ag_scm_out_suspend(SCM suspName)
+ag_scm_out_suspend(SCM susp_nm)
 {
     if (pCurFp->pPrev == NULL)
         AG_ABEND("ERROR:  Cannot pop output with no output pushed");
@@ -233,7 +367,7 @@ ag_scm_out_suspend(SCM suspName)
                          "augmenting suspended file list");
     }
 
-    pSuspended[ suspendCt-1 ].pzSuspendName = gh_scm2newstr(suspName, NULL);
+    pSuspended[ suspendCt-1 ].pzSuspendName = gh_scm2newstr(susp_nm, NULL);
     pSuspended[ suspendCt-1 ].pOutDesc      = pCurFp;
     if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
         fprintf(pfTrace, "suspended output to '%s'\n",
@@ -249,17 +383,17 @@ ag_scm_out_suspend(SCM suspName)
 /*=gfunc out_resume
  *
  * what:   resume suspended output file
- * exparg: suspName, A name tag for reactivating
+ * exparg: susp_nm, A name tag for reactivating
  * doc:
  *  If there has been a suspended output, then make that output descriptor
  *  current again.  That output must have been suspended with the same tag
  *  name given to this routine as its argument.
 =*/
 SCM
-ag_scm_out_resume(SCM suspName)
+ag_scm_out_resume(SCM susp_nm)
 {
     int  ix  = 0;
-    char const * pzName = ag_scm2zchars(suspName, "resume name");
+    char const * pzName = ag_scm2zchars(susp_nm, "resume name");
 
     for (; ix < suspendCt; ix++) {
         if (strcmp(pSuspended[ ix ].pzSuspendName, pzName) == 0) {
@@ -285,15 +419,15 @@ ag_scm_out_resume(SCM suspName)
 /*=gfunc out_emit_suspended
  *
  * what:   emit the text of suspended output
- * exparg: suspName, A name tag of suspended output
+ * exparg: susp_nm, A name tag of suspended output
  * doc:
  *  This function is equivalent to
  *  @code{(begin (out-resume <name>) (out-pop #t))}
 =*/
 SCM
-ag_scm_out_emit_suspended(SCM suspName)
+ag_scm_out_emit_suspended(SCM susp_nm)
 {
-    (void)ag_scm_out_resume(suspName);
+    (void)ag_scm_out_resume(susp_nm);
     return ag_scm_out_pop(SCM_BOOL_T);
 }
 
@@ -376,49 +510,6 @@ ag_scm_ag_fprintf(SCM port, SCM fmt, SCM alist)
     return SCM_UNDEFINED;
 }
 
-
-/*
- * Some common code for creating a new file
- */
-LOCAL void
-open_output_file(char const * fname, size_t nmsz, char const * mode, int flags)
-{
-    char *    pz;
-    tFpStack* p  = AGALOC(sizeof(*p), "out file stack");
-
-    pz = (char*)AGALOC(nmsz + 1, "file name string");
-    memcpy(pz, fname, nmsz);
-    pz[ nmsz ] = NUL;
-    memset(p, NUL, sizeof(*p));
-    p->pzOutName = pz;
-
-    /*
-     *  IF we are creating the file and we are allowed to unlink the output,
-     *  then start by unlinking the thing.
-     */
-    if ((*mode == 'w') && ((flags & FPF_NOUNLINK) == 0)) {
-        if ((unlink(pz) != 0) && (errno != ENOENT))
-            AG_CANT("unlink", pz);
-    }
-
-    p->pFile = fopen(pz, mode);
-    if (p->pFile == NULL)
-        AG_CANT("open for output", pz);
-
-    p->pPrev = pCurFp;
-    pCurFp   = p;
-    p->flags = FPF_FREE | flags;
-    outputDepth++;
-
-    make_writable(pz);
-
-    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-        fprintf(pfTrace, "open_output_file '%s' mode %s\n", fname, mode);
-
-    if ((pfDepends != NULL) && ((flags & FPF_TEMPFILE) == 0))
-        fprintf(pfDepends, " \\\n\t%s", fname);
-}
-
 /*=gfunc out_push_add
  *
  * what:   append output to file
@@ -515,7 +606,7 @@ ag_scm_out_push_new(SCM new_file)
         p = (tFpStack*)AGALOC(sizeof(tFpStack), "out file stack");
         p->pPrev  = pCurFp;
         p->flags  = FPF_FREE;
-        p->pFile  = ag_fmemopen(NULL, (size_t)0, "wb+");
+        p->pFile  = ag_fmemopen(NULL, (ssize_t)0, "wb+");
         pzNewFile = (char*)zMemFile;
         p->flags |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
 
@@ -661,6 +752,8 @@ ag_scm_out_line(void)
 }
 
 #if 0 /* for compilers that do not like C++ comments... */
+// This is done so that comment delimiters can be included in the doc.
+//
 // /*=gfunc   make_header_guard
 //  *
 //  * what:   make self-inclusion guard
