@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Jul 25 09:16:24 PDT 2010
+ * Generated Tue Sep  7 17:54:49 PDT 2010
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -16,7 +16,7 @@
  *  Extracted from agCgi.c
  */
 LOCAL void
-loadCgi( void );
+loadCgi(void);
 
 /*
  *  Extracted from agInit.c
@@ -31,21 +31,19 @@ config_dep(tOptions* pOptions, tOptDesc* pOptDesc);
  *  Extracted from agShell.c
  */
 LOCAL void
-closeServer( void );
+close_server_shell(void);
 
 LOCAL int
-chainOpen( int       stdinFd,
-           tCC**     ppArgs,
-           pid_t*    pChild  );
+chainOpen(int stdinFd, char const ** ppArgs, pid_t * pChild);
 
 LOCAL pid_t
-openServer( tFdPair* pPair, tCC** ppArgs );
+openServer(tFdPair* pPair, tCC** ppArgs);
 
 LOCAL pid_t
-openServerFP( tpfPair* pfPair, tCC** ppArgs );
+openServerFP(tpfPair* pfPair, tCC** ppArgs);
 
 LOCAL char*
-runShell( char const*  pzCmd );
+runShell(char const*  pzCmd);
 
 /*
  *  Extracted from agUtils.c
@@ -97,7 +95,7 @@ ao_strdup (char const * str);
  *  Extracted from defDirect.c
  */
 LOCAL char*
-processDirective( char* pzScan );
+processDirective(char* pzScan);
 
 /*
  *  Extracted from defFind.c
