@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for autoopts
- * Generated Fri Jun 25 14:11:11 PDT 2010
+ * Generated Tue Sep  7 17:54:30 PDT 2010
  */
 #ifndef AUTOOPTS_PROTO_H_GUARD
 #define AUTOOPTS_PROTO_H_GUARD 1
@@ -16,37 +16,37 @@
  *  Extracted from autoopts.c
  */
 LOCAL void *
-ao_malloc( size_t sz );
+ao_malloc(size_t sz);
 
 LOCAL void *
-ao_realloc( void *p, size_t sz );
+ao_realloc(void *p, size_t sz);
 
 LOCAL void
-ao_free( void *p );
+ao_free(void *p);
 
 LOCAL char *
-ao_strdup( char const *str );
+ao_strdup(char const *str);
 
 LOCAL tSuccess
-handleOption( tOptions* pOpts, tOptState* pOptState );
+handleOption(tOptions* pOpts, tOptState* pOptState);
 
 LOCAL tSuccess
-longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState );
+longOptionFind(tOptions* pOpts, char* pzOptName, tOptState* pOptState);
 
 LOCAL tSuccess
-shortOptionFind( tOptions* pOpts, uint_t optValue, tOptState* pOptState );
+shortOptionFind(tOptions* pOpts, uint_t optValue, tOptState* pOptState);
 
 LOCAL tSuccess
-doImmediateOpts( tOptions* pOpts );
+doImmediateOpts(tOptions* pOpts);
 
 LOCAL tSuccess
-doRegularOpts( tOptions* pOpts );
+doRegularOpts(tOptions* pOpts);
 
 /*
  *  Extracted from configfile.c
  */
 LOCAL void
-internalFileLoad( tOptions* pOpts );
+internalFileLoad(tOptions* pOpts);
 
 LOCAL char*
 parseAttributes(
@@ -56,22 +56,22 @@ parseAttributes(
     tOptionValue*       pType );
 
 LOCAL tSuccess
-validateOptionsStruct( tOptions* pOpts, char const* pzProgram );
+validateOptionsStruct(tOptions* pOpts, char const* pzProgram);
 
 /*
  *  Extracted from environment.c
  */
 LOCAL void
-doPrognameEnv( tOptions* pOpts, teEnvPresetType type );
+doPrognameEnv(tOptions* pOpts, teEnvPresetType type);
 
 LOCAL void
-doEnvPresets( tOptions* pOpts, teEnvPresetType type );
+doEnvPresets(tOptions* pOpts, teEnvPresetType type);
 
 /*
  *  Extracted from load.c
  */
 LOCAL void
-mungeString( char* pzTxt, tOptionLoadMode mode );
+mungeString(char* pzTxt, tOptionLoadMode mode);
 
 LOCAL void
 loadOptionLine(
@@ -84,6 +84,9 @@ loadOptionLine(
 /*
  *  Extracted from nested.c
  */
+LOCAL void
+unload_arg_list(tArgList* pAL);
+
 LOCAL tOptionValue*
 optionLoadNested(char const* pzTxt, char const* pzName, size_t nameLen);
 
@@ -97,13 +100,13 @@ emit_special_char(FILE * fp, int ch);
  *  Extracted from sort.c
  */
 LOCAL void
-optionSort( tOptions* pOpts );
+optionSort(tOptions* pOpts);
 
 /*
  *  Extracted from stack.c
  */
 LOCAL void
-addArgListEntry( void** ppAL, void* entry );
+addArgListEntry(void** ppAL, void* entry);
 
 #ifdef REDEF_LOCAL
 #  undef LOCAL
